@@ -3,7 +3,7 @@
 from rayvision_maya.analyze_maya import AnalyzeMaya
 
 analyze_info = {
-    "cg_file": r"D:\gitlab\renderSDK\renderSDK\CG\cg_maya\muti_layer_test.ma",
+    "cg_file": r"D:\houdini\CG file\muti_layer_test.ma",
     "workspace": "c:/workspace",
     "software_version": "2018",
     "project_name": "Project1",
@@ -13,10 +13,3 @@ analyze_info = {
 }
 
 AnalyzeMaya(**analyze_info).analyse()
-
-
-
-
-
-
-
